from dnsimple.struct.struct import Struct
from dnsimple.struct.access_token import AccessToken
from dnsimple.struct.account import Account
from dnsimple.struct.certificate import Certificate, CertificateBundle, LetsencryptCertificateInput, CertificatePurchase, CertificateRenewal
from dnsimple.struct.collaborator import Collaborator
from dnsimple.struct.contact import Contact
from dnsimple.struct.dnssec import Dnssec
from dnsimple.struct.delegation_signer_record import DelegationSignerRecord, DelegationSignerRecordInput
from dnsimple.struct.domain import Domain
from dnsimple.struct.domain_check import DomainCheck
from dnsimple.struct.domain_premium_price import DomainPremiumPrice, DomainPremiumPriceOptions
from dnsimple.struct.domain_price import DomainPrice
from dnsimple.struct.domain_registration import DomainRegistration, DomainRegistrationRequest
from dnsimple.struct.domain_renewal import DomainRenewal, DomainRenewRequest
from dnsimple.struct.domain_transfer import DomainTransfer, DomainTransferRequest
from dnsimple.struct.domain_push import DomainPush
from dnsimple.struct.email_forward import EmailForward, EmailForwardInput
from dnsimple.struct.service import Service
from dnsimple.struct.template import Template
from dnsimple.struct.template_record import TemplateRecord
from dnsimple.struct.tld import Tld, TldExtendedAttribute, TldExtendedAttributeOption
from dnsimple.struct.user import User
from dnsimple.struct.vanity_name_server import VanityNameServer
from dnsimple.struct.webhook import Webhook
from dnsimple.struct.whoami import Whoami
from dnsimple.struct.whois_privacy import WhoisPrivacy, WhoisPrivacyRenewal
from dnsimple.struct.zone import Zone
from dnsimple.struct.zone_distribution import ZoneDistribution
from dnsimple.struct.zone_file import ZoneFile
from dnsimple.struct.zone_record import ZoneRecord, ZoneRecordInput, ZoneRecordUpdateInput



from dataclasses import dataclass

from dnsimple.struct import Struct


@dataclass
class EmailForward(Struct):
    id = None
    """The email forward ID in DNSimple"""
    domain_id = None
    """The associated domain ID"""
    email_from = None
    """The "local part" of the originating email address. Anything to the left of the @ symbol"""
    email_to = None
    """The full email address to forward to"""
    created_at = None
    """When the email forward was created in DNSimple"""
    updated_at = None
    """When the email forward was last updated in DNSimple"""

    def __init__(self, data):
        super().__init__(data)
        setattr(self, 'email_from', data['from'])
        setattr(self, 'email_to', self.to)


@dataclass
class EmailForwardInput(object):
    def __init__(self, email_from, email_to):
        self.email_from = email_from
        self.email_to = email_to
